package main

import (
    "assignment1/handlers" 
    "log"
    "net/http"
    "os"
    "time"
)

func main() {
    mux := http.NewServeMux()

    mux.HandleFunc("/librarystats/v1/bookcount/", handlers.BookCountHandler)
    mux.HandleFunc("/librarystats/v1/readership/", handlers.ReadershipHandler)
    mux.HandleFunc("/librarystats/v1/status/", handlers.StatusHandler)

    // Use the PORT environment variable
    port := os.Getenv("PORT")
    if port == "" {
        port = "8080" // Default to 8080 if no PORT environment variable is specified
        log.Printf("Defaulting to port %s", port)
    }

    srv := &http.Server{
        Handler:      mux,
        Addr:         ":" + port, // Listen on the port specified by the PORT environment variable
        WriteTimeout: 15 * time.Second,
        ReadTimeout:  15 * time.Second,
    }

    log.Printf("Listening on port %s", port)
    if err := srv.ListenAndServe(); err != nil {
        log.Fatalf("Failed to start server: %v", err)
    }
}
