package models

// GutenbergBook represents the structure of a book from the Gutenberg API.
type GutenbergBook struct {
    ID            int               `json:"id"`
    Title         string            `json:"title"`
    Authors       []Person          `json:"authors"`
    Translators   []Person          `json:"translators"`
    Subjects      []string          `json:"subjects"`
    Bookshelves   []string          `json:"bookshelves"`
    Languages     []string          `json:"languages"`
    Copyright     bool              `json:"copyright"`
    MediaType     string            `json:"media_type"`
    Formats       map[string]string `json:"formats"`
    DownloadCount int               `json:"download_count"`
}

// GutenbergResponse represents the paginated response from Gutenberg API.
type GutenbergResponse struct {
    Count    int              `json:"count"`
    Next     string           `json:"next"`
    Previous string           `json:"previous"`
    Results  []GutenbergBook  `json:"results"`
}

// Person represents an author or translator.
type Person struct {
    BirthYear *int   `json:"birth_year"`
    DeathYear *int   `json:"death_year"`
    Name      string `json:"name"`
}

// LanguageCountriesResponse represents the response structure from the Language2Countries API.
type LanguageCountriesResponse struct {
    Countries []CountryInfo `json:"countries"`
}

// CountryInfo represents country information in the LanguageCountriesResponse.
type CountryInfo struct {
    ISO3166_1_Alpha_3 string `json:"ISO3166_1_Alpha_3"`
    ISO3166_1_Alpha_2 string `json:"ISO3166_1_Alpha_2"`
    Official_Name     string `json:"Official_Name"`
    Region_Name       string `json:"Region_Name"`
    Sub_Region_Name   string `json:"Sub_Region_Name"`
    Language          string `json:"Language"`
}

// CountryResponse represents the structure of a country response from the REST Countries API.
type CountryResponse struct {
    Population int64 `json:"population"`
}

// ReadershipDetail represents the detailed readership information for a country.
type ReadershipDetail struct {
    Country    string `json:"country"`
    ISOCode    string `json:"isocode"`
    Books      int    `json:"books"`
    Authors    int    `json:"authors"`
    Readership int64  `json:"readership"`
}

// ServiceStatus represents the status of external services your application depends on.
type ServiceStatus struct {
    GutendexAPI  string `json:"gutendexapi"`
    LanguageAPI  string `json:"languageapi"`
    CountriesAPI string `json:"countriesapi"`
    Version      string `json:"version"`
    Uptime       int64  `json:"uptime"`
}
